==> aws-java-sdk-1.2.15-sources.jar: com/amazonaws/services/elasticmapreduce/model/transform/JobFlowDetailStaxUnmarshaller.java <==
/*
 * Copyright 2010-2011 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.elasticmapreduce.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.elasticmapreduce.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;


/**
 * Job Flow Detail StAX Unmarshaller
 */
public class JobFlowDetailStaxUnmarshaller implements Unmarshaller<JobFlowDetail, StaxUnmarshallerContext> {

    public JobFlowDetail unmarshall(StaxUnmarshallerContext context) throws Exception {
        JobFlowDetail jobFlowDetail = new JobFlowDetail();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        
        if (context.isStartOfDocument()) targetDepth += 2;
        

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return jobFlowDetail;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("JobFlowId", targetDepth)) {
                    jobFlowDetail.setJobFlowId(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("Name", targetDepth)) {
                    jobFlowDetail.setName(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("LogUri", targetDepth)) {
                    jobFlowDetail.setLogUri(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("AmiVersion", targetDepth)) {
                    jobFlowDetail.setAmiVersion(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("ExecutionStatusDetail", targetDepth)) {
                    jobFlowDetail.setExecutionStatusDetail(JobFlowExecutionStatusDetailStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("Instances", targetDepth)) {
                    jobFlowDetail.setInstances(JobFlowInstancesDetailStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("Steps/member", targetDepth)) {
                    jobFlowDetail.getSteps().add(StepDetailStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("BootstrapActions/member", targetDepth)) {
                    jobFlowDetail.getBootstrapActions().add(BootstrapActionDetailStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("SupportedProducts/member", targetDepth)) {
                    jobFlowDetail.getSupportedProducts().add(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return jobFlowDetail;
                }
            }
        }
    }

    private static JobFlowDetailStaxUnmarshaller instance;
    public static JobFlowDetailStaxUnmarshaller getInstance() {
        if (instance == null) instance = new JobFlowDetailStaxUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-1.3.27-sources.jar: com/amazonaws/services/elasticmapreduce/model/transform/JobFlowDetailStaxUnmarshaller.java <==
/*
 * Copyright 2010-2012 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.elasticmapreduce.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.elasticmapreduce.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;


/**
 * Job Flow Detail StAX Unmarshaller
 */
public class JobFlowDetailStaxUnmarshaller implements Unmarshaller<JobFlowDetail, StaxUnmarshallerContext> {

    public JobFlowDetail unmarshall(StaxUnmarshallerContext context) throws Exception {
        JobFlowDetail jobFlowDetail = new JobFlowDetail();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        
        if (context.isStartOfDocument()) targetDepth += 2;
        

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return jobFlowDetail;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("JobFlowId", targetDepth)) {
                    jobFlowDetail.setJobFlowId(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("Name", targetDepth)) {
                    jobFlowDetail.setName(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("LogUri", targetDepth)) {
                    jobFlowDetail.setLogUri(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("AmiVersion", targetDepth)) {
                    jobFlowDetail.setAmiVersion(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("ExecutionStatusDetail", targetDepth)) {
                    jobFlowDetail.setExecutionStatusDetail(JobFlowExecutionStatusDetailStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("Instances", targetDepth)) {
                    jobFlowDetail.setInstances(JobFlowInstancesDetailStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("Steps/member", targetDepth)) {
                    jobFlowDetail.getSteps().add(StepDetailStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("BootstrapActions/member", targetDepth)) {
                    jobFlowDetail.getBootstrapActions().add(BootstrapActionDetailStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("SupportedProducts/member", targetDepth)) {
                    jobFlowDetail.getSupportedProducts().add(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("VisibleToAllUsers", targetDepth)) {
                    jobFlowDetail.setVisibleToAllUsers(BooleanStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return jobFlowDetail;
                }
            }
        }
    }

    private static JobFlowDetailStaxUnmarshaller instance;
    public static JobFlowDetailStaxUnmarshaller getInstance() {
        if (instance == null) instance = new JobFlowDetailStaxUnmarshaller();
        return instance;
    }
}
